@@ -4,17 +4,17 @@ from collections import defaultdict
 
 import numpy as np
 import pandas as pd
-from six import iteritems
 
 from bokeh.charts import DEFAULT_PALETTE
 from bokeh.core.enums import DashPattern
-from bokeh.models.glyphs import Rect, Segment, Line, Patches
+from bokeh.models.glyphs import Rect, Segment, Line, Patches, Arc
 from bokeh.models.renderers import GlyphRenderer
 from bokeh.core.properties import (Float, String, Datetime, Bool, Instance,
-                                   List, Either, Int, Enum, Color, Override, Any)
+                                   List, Either, Int, Enum, Color, Override, Any, Angle)
 from .models import CompositeGlyph
 from .properties import Column, EitherColumn
-from .stats import Stat, Quantile, Sum, Min, Max, Bins, stats
+from .stats import (Stat, Quantile, Sum, Min, Max, Bins, stats, Histogram,
+                    BinnedStat)
 from .data_source import ChartDataSource
 from .utils import marker_types, generate_patch_base, label_from_index_dict
 
@@ -200,9 +200,9 @@ class AreaGlyph(LineGlyph):
     base = Float(default=0.0, help="""Lower bound of area.""")
 
     def __init__(self, **kwargs):
-        line_color = kwargs.get('line_color', None)
-        fill_color = kwargs.get('fill_color', None)
-        color = kwargs.get('color', None)
+        line_color = kwargs.get('line_color')
+        fill_color = kwargs.get('fill_color')
+        color = kwargs.get('color')
 
         if color is not None:
             # apply color to line and fill
@@ -411,8 +411,8 @@ class HorizonGlyph(AreaGlyph):
 
         # transform clipped data so it always starts and ends at its base value
         if len(ys) > 0:
-            xs, ys = map(list, zip(*[generate_patch_base(x, y, base=base) for
-                                     x, y in zip(xs, ys)]))
+            xs, ys = map(list, zip(*[generate_patch_base(xx, yy, base=base) for
+                                     xx, yy in zip(xs, ys)]))
 
         return xs, ys
 
@@ -439,11 +439,13 @@ class StepGlyph(LineGlyph):
         elif self.y is None:
             y = self.x.index
 
-        xs = np.empty(2*len(x)-1, dtype=np.int)
+        dtype = x.dtype if hasattr(x, 'dtype') else np.int
+        xs = np.empty(2*len(x)-1, dtype=dtype)
         xs[::2] = x[:]
         xs[1::2] = x[1:]
 
-        ys = np.empty(2*len(y)-1)
+        dtype = y.dtype if hasattr(y, 'dtype') else np.float64
+        ys = np.empty(2*len(y)-1, dtype=dtype)
         ys[::2] = y[:]
         ys[1::2] = y[:-1]
 
@@ -600,10 +602,7 @@ class Interval(AggregateGlyph):
 
     def get_end(self):
         """Get the value for the end of the glyph."""
-        if len(self.values.index) == 1 and not self.values.dtype.name == 'object':
-            self.end_agg = None
-            return self.values[0]
-        elif isinstance(self.end_agg, str):
+        if isinstance(self.end_agg, str):
             self.end_agg = stats[self.end_agg]()
 
         self.end_agg.set_data(self.values)
@@ -630,9 +629,11 @@ class Interval(AggregateGlyph):
         fill_alpha = [self.fill_alpha]
         line_color = [self.line_color]
         line_alpha = [self.line_alpha]
+        label = [self.label]
+
         return dict(x=x, y=y, width=width, height=height, color=color,
                     fill_alpha=fill_alpha, line_color=line_color,
-                    line_alpha=line_alpha)
+                    line_alpha=line_alpha, label=label)
 
     @property
     def x_max(self):
@@ -804,7 +805,7 @@ class BoxGlyph(AggregateGlyph):
     def __init__(self, label, values, outliers=True, **kwargs):
         width = kwargs.pop('width', None)
 
-        bar_color = kwargs.pop('color', None) or kwargs.get('bar_color', None) or self.lookup('bar_color').class_default()
+        bar_color = kwargs.pop('color', None) or kwargs.get('bar_color') or self.lookup('bar_color').class_default()
 
         kwargs['outliers'] = kwargs.pop('outliers', None) or outliers
         kwargs['label'] = label
@@ -913,27 +914,38 @@ class HistogramGlyph(AggregateGlyph):
     options for displaying it, such as KDE and cumulative density.
     """
 
-    # input properties
-    bin_width = Float()
-    bin_count = Float(help="""Provide a manually specified number of bins to use.""")
-
     # derived models
-    bins = Instance(Bins, help="""A stat used to calculate the bins. The bins stat
+    bins = Instance(BinnedStat, help="""A stat used to calculate the bins. The bins stat
         includes attributes about each composite bin.""")
     bars = List(Instance(BarGlyph), help="""The histogram is comprised of many
         BarGlyphs that are derived from the values.""")
+    density = Bool(False, help="""
+        Whether to normalize the histogram.
 
-    def __init__(self, values, label=None, color=None, bin_count=None, **kwargs):
+        If True, the result is the value of the probability *density* function
+        at the bin, normalized such that the *integral* over the range is 1. If
+        False, the result will contain the number of samples in each bin.
+
+        For more info check :class:`~bokeh.charts.stats.Histogram` documentation.
+
+        (default: False)
+    """)
+
+    def __init__(self, values, label=None, color=None, bins=None, **kwargs):
         if label is not None:
             kwargs['label'] = label
         kwargs['values'] = values
-        kwargs['bin_count'] = bin_count
+
         if color is not None:
             kwargs['color'] = color
 
         # remove width, since this is handled automatically
         kwargs.pop('width', None)
 
+        # keep original bins setting private since it just needs to be
+        # delegated to the Histogram stat
+        self._bins = bins
+
         super(HistogramGlyph, self).__init__(**kwargs)
         self.setup()
 
@@ -947,20 +959,20 @@ class HistogramGlyph(AggregateGlyph):
 
     def build_renderers(self):
         """Yield a bar glyph for each bin."""
-        self.bins = Bins(values=self.values, bin_count=self.bin_count)
-        centers = [bin.center for bin in self.bins.bins]
-        self.bin_width = centers[1] - centers[0]
+        # TODO(fpliger): We should expose the bin stat class so we could let
+        #               users specify other bins other the Histogram Stat
+        self.bins = Histogram(values=self.values, bins=self._bins,
+            density=self.density)
 
         bars = []
         for bin in self.bins.bins:
-            bars.append(BarGlyph(label=self.label, x_label=bin.center,
+            bars.append(BarGlyph(label=bin.label[0], x_label=bin.center,
                                  values=bin.values, color=self.color,
                                  fill_alpha=self.fill_alpha,
-                                 agg=bin.stat, width=self.bin_width))
+                                 agg=bin.stat, width=bin.width))
 
         # provide access to bars as children for bounds properties
-        self.bars = bars
-        self.children = self.bars
+        self.bars = self.children = bars
 
         for comp_glyph in self.bars:
             for renderer in comp_glyph.renderers:
@@ -1034,3 +1046,21 @@ class BinGlyph(XyGlyph):
             return min(data), max(data)
         else:
             return 1, len(data.drop_duplicates())
+
+
+class ArcGlyph(LineGlyph):
+    """Represents a group of data as an arc."""
+    start_angle = Angle()
+    end_angle = Angle()
+
+    def __init__(self, **kwargs):
+        super(self.__class__, self).__init__(**kwargs)
+        self.setup()
+
+    def build_renderers(self):
+        """Yield a `GlyphRenderer` for the group of data."""
+        glyph = Arc(x='x', y='y', radius=1,
+                    start_angle='_end_angle',
+                    end_angle='_start_angle',
+                    line_color='line_color')
+        yield GlyphRenderer(glyph=glyph)
