@@ -8,7 +8,22 @@ from __future__ import absolute_import
 import logging
 logger = logging.getLogger(__file__)
 
-from functools import wraps
+# There is a problem with using @wraps decorator in combination with functools.partial.
+# This issue is not present in Python 3.
+# This redefinition will be triggered only if issue affects user,
+# otherwise regular definition of @wraps will be used.
+#
+# this code snippet was originally posted in followig stack overflow discussion:
+# http://stackoverflow.com/a/28752007
+
+from functools import wraps, partial, WRAPPER_ASSIGNMENTS
+try:
+    wraps(partial(wraps))(wraps)
+except AttributeError:
+    @wraps(wraps)
+    def wraps(obj, attr_names=WRAPPER_ASSIGNMENTS, wraps=wraps):
+        return wraps(obj, assigned=(name for name in attr_names if hasattr(obj, name)))
+
 from json import loads
 
 import jinja2
@@ -110,11 +125,23 @@ class ColumnsStreamedEvent(DocumentPatchedEvent):
         if hasattr(receiver, '_columns_streamed'):
             receiver._columns_streamed(self)
 
+class ColumnsPatchedEvent(DocumentPatchedEvent):
+    def __init__(self, document, column_source, patches):
+        super(ColumnsPatchedEvent, self).__init__(document)
+        self.column_source = column_source
+        self.patches = patches
+
+    def dispatch(self, receiver):
+        super(ModelChangedEvent, self).dispatch(receiver)
+        if hasattr(receiver, '_columns_patched'):
+            receiver._columns_patched(self)
+
 class TitleChangedEvent(DocumentPatchedEvent):
     def __init__(self, document, title):
         super(TitleChangedEvent, self).__init__(document)
         self.title = title
 
+
 class RootAddedEvent(DocumentPatchedEvent):
     def __init__(self, document, model):
         super(RootAddedEvent, self).__init__(document)
@@ -212,7 +239,7 @@ class _MultiValuedDict(object):
             raise ValueError("Can't put None in this dict")
         if isinstance(value, set):
             raise ValueError("Can't put sets in this dict")
-        existing = self._dict.get(key, None)
+        existing = self._dict.get(key)
         if existing is None:
             self._dict[key] = value
         elif isinstance(existing, set):
@@ -223,7 +250,7 @@ class _MultiValuedDict(object):
     def remove_value(self, key, value):
         if key is None:
             raise ValueError("Key is None")
-        existing = self._dict.get(key, None)
+        existing = self._dict.get(key)
         if isinstance(existing, set):
             existing.discard(value)
             if len(existing) == 0:
@@ -234,7 +261,7 @@ class _MultiValuedDict(object):
             pass
 
     def get_one(self, k, duplicate_error):
-        existing = self._dict.get(k, None)
+        existing = self._dict.get(k)
         if isinstance(existing, set):
             if len(existing) == 1:
                 return next(iter(existing))
@@ -244,7 +271,7 @@ class _MultiValuedDict(object):
             return existing
 
     def get_all(self, k):
-        existing = self._dict.get(k, None)
+        existing = self._dict.get(k)
         if existing is None:
             return []
         elif isinstance(existing, set):
@@ -270,6 +297,7 @@ class Document(object):
         self._all_models_by_name = _MultiValuedDict()
         self._callbacks = {}
         self._session_callbacks = {}
+        self._session_context = None
 
     def clear(self):
         ''' Remove all content from the document (including roots, vars, stores) but do not reset title'''
@@ -346,6 +374,10 @@ class Document(object):
     def roots(self):
         return list(self._roots)
 
+    @property
+    def session_context(self):
+        return self._session_context
+
     @property
     def title(self):
         return self._title
@@ -390,6 +422,7 @@ class Document(object):
         for model in self._all_models.values():
             self._theme.apply_to_model(model)
 
+
     def add_root(self, model):
         ''' Add a model as a root model to this Document.
 
@@ -448,7 +481,7 @@ class Document(object):
 
     def get_model_by_id(self, model_id):
         ''' Get the model object for the given ID or None if not found'''
-        return self._all_models.get(model_id, None)
+        return self._all_models.get(model_id)
 
     def get_model_by_name(self, name):
         ''' Get the model object for the given name or None if not found'''
@@ -672,8 +705,8 @@ class Document(object):
                                                                value_refs))
 
         for key in shared:
-            old_value = from_obj['attributes'].get(key, None)
-            new_value = to_obj['attributes'].get(key, None)
+            old_value = from_obj['attributes'].get(key)
+            new_value = to_obj['attributes'].get(key)
 
             if old_value is None and new_value is None:
                 continue
@@ -844,6 +877,11 @@ class Document(object):
                                          'column_source' : event.hint.column_source.ref,
                                          'data' : event.hint.data,
                                          'rollover' : event.hint.rollover })
+
+                elif isinstance(event.hint, ColumnsPatchedEvent):
+                    json_events.append({ 'kind' : 'ColumnsPatched',
+                                         'column_source' : event.hint.column_source.ref,
+                                         'patches' : event.hint.patches })
                 else:
                     value = event.serializable_new
 
@@ -925,11 +963,18 @@ class Document(object):
             elif event_json['kind'] == 'ColumnsStreamed':
                 source_id = event_json['column_source']['id']
                 if source_id not in self._all_models:
-                    raise RuntimeError("Cannot apply patch to %s which is not in the document" % (str(source_id)))
+                    raise RuntimeError("Cannot stream to %s which is not in the document" % (str(source_id)))
                 source = self._all_models[source_id]
                 data = event_json['data']
                 rollover = event_json['rollover']
                 source.stream(data, rollover)
+            elif event_json['kind'] == 'ColumnsPatched':
+                source_id = event_json['column_source']['id']
+                if source_id not in self._all_models:
+                    raise RuntimeError("Cannot apply patch to %s which is not in the document" % (str(source_id)))
+                source = self._all_models[source_id]
+                patches = event_json['patches']
+                source.patch(patches)
             elif event_json['kind'] == 'RootAdded':
                 root_id = event_json['model']['id']
                 root_obj = references[root_id]
