@@ -290,6 +290,39 @@ class Gear(Glyph):
     The %s values for the gears.
     """)
 
+class HBar(Glyph):
+    """ Render horizontal bars, given a center coordinate, height and (left, right) coordinates. """
+
+    __example__ = "tests/glyphs/HBar.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('y', 'height', 'left', 'right')
+
+    y = NumberSpec(help="""
+    The y-coordinates of the centers of the horizontal bars.
+    """)
+
+    height = NumberSpec(help="""
+    The heights of the vertical bars.
+    """)
+
+    left = NumberSpec(default=0, help="""
+    The x-coordinates of the left edges.
+    """)
+
+    right = NumberSpec(help="""
+    The x-coordinates of the right edges.
+    """)
+
+    line_props = Include(LineProps, use_prefix=False, help="""
+    The %s values for the horizontal bars.
+    """)
+
+    fill_props = Include(FillProps, use_prefix=False, help="""
+    The %s values for the horizontal bars.
+    """)
+
 class Image(Glyph):
     """ Render images given as scalar data together with a color mapper. """
 
@@ -300,15 +333,6 @@ class Image(Glyph):
             # Use a palette (given or default)
             palette = kwargs.pop('palette', 'Greys9')
             mapper = LinearColorMapper(palette)
-
-            reserve_val = kwargs.pop('reserve_val', None)
-            if reserve_val is not None:
-                mapper.reserve_val = reserve_val
-
-            reserve_color = kwargs.pop('reserve_color', None)
-            if reserve_color is not None:
-                mapper.reserve_color = reserve_color
-
             kwargs['color_mapper'] = mapper
 
         super(Image, self).__init__(**kwargs)
@@ -893,6 +917,39 @@ class Text(Glyph):
     The %s values for the text.
     """)
 
+class VBar(Glyph):
+    """ Render vertical bars, given a center coordinate, width and (top, bottom) coordinates. """
+
+    __example__ = "tests/glyphs/VBar.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('x', 'width', 'top', 'bottom')
+
+    x = NumberSpec(help="""
+    The x-coordinates of the centers of the vertical bars.
+    """)
+
+    width = NumberSpec(help="""
+    The widths of the vertical bars.
+    """)
+
+    bottom = NumberSpec(default=0, help="""
+    The y-coordinates of the bottom edges.
+    """)
+
+    top = NumberSpec(help="""
+    The y-coordinates of the top edges.
+    """)
+
+    line_props = Include(LineProps, use_prefix=False, help="""
+    The %s values for the vertical bars.
+    """)
+
+    fill_props = Include(FillProps, use_prefix=False, help="""
+    The %s values for the vertical bars.
+    """)
+
 class Wedge(Glyph):
     """ Render wedges.
     """
