@@ -8,59 +8,39 @@ import warnings
 
 from ..core.query import find
 from ..core import validation
-from ..core.validation.warnings import (MISSING_RENDERERS, NO_DATA_RENDERERS,
-    EMPTY_LAYOUT, MALFORMED_CATEGORY_LABEL)
-from ..core.enums import Location
-from ..core.property_mixins import LineProps, TextProps, FillProps
-from ..model import Model
-from ..core.properties import (Bool, Int, String, Enum, Auto, Instance, Either,
-    List, Dict, Include, Override)
-from ..util.string import nice_join
 from ..core.validation.errors import REQUIRED_RANGE
+from ..core.validation.warnings import (
+    MISSING_RENDERERS, NO_DATA_RENDERERS, MALFORMED_CATEGORY_LABEL,
+    SNAPPED_TOOLBAR_ANNOTATIONS)
+from ..core.enums import Location
+from ..core.property_mixins import LineProps, FillProps
+from ..core.properties import (
+    Bool, Int, String, Enum, Auto, Instance, Either,
+    List, Dict, Include, Override, TitleProp)
+from ..util.string import nice_join
 
+from .annotations import Legend, Title
+from .axes import Axis
 from .glyphs import Glyph
-from .ranges import Range, Range1d, FactorRange
+from .grids import Grid
+from .ranges import Range, FactorRange
 from .renderers import Renderer, GlyphRenderer, DataRenderer, TileRenderer, DynamicImageRenderer
 from .sources import DataSource, ColumnDataSource
-from .tools import Tool, ToolEvents
-from .component import Component
+from .tools import Tool, ToolEvents, Toolbar
+from .layouts import LayoutDOM
 
-def _select_helper(args, kwargs):
+from ..util.plot_utils import _list_attr_splat, _select_helper
+
+# See all the way at the bottom of Plot for where this is used.
+DEP_MSG_0_12_0 = """
+    Plot property '%s' was deprecated in 0.12.0 and will be removed. Use '%s' instead.
     """
-    Allow flexible selector syntax.
-    Returns:
-        a dict
-    """
-    if len(args) > 1:
-        raise TypeError("select accepts at most ONE positional argument.")
 
-    if len(args) > 0 and len(kwargs) > 0:
-        raise TypeError("select accepts EITHER a positional argument, OR keyword arguments (not both).")
+# We create an empty title by default
+DEFAULT_TITLE = lambda: Title(text="")
 
-    if len(args) == 0 and len(kwargs) == 0:
-        raise TypeError("select requires EITHER a positional argument, OR keyword arguments.")
 
-    if args:
-        arg = args[0]
-        if isinstance(arg, dict):
-            selector = arg
-        elif isinstance(arg, string_types):
-            selector = dict(name=arg)
-        elif issubclass(arg, Model):
-            selector = {"type" : arg}
-        else:
-            raise RuntimeError("Selector must be a dictionary, string or plot object.")
-
-    else:
-        selector = kwargs
-    return selector
-
-class LayoutBox(Model):
-    ''' Represents an **on-canvas** layout.
-
-    '''
-
-class Plot(Component):
+class Plot(LayoutDOM):
     """ Model representing a plot, containing glyphs, guides, annotations.
 
     """
@@ -69,13 +49,25 @@ class Plot(Component):
         if "tool_events" not in kwargs:
             kwargs["tool_events"] = ToolEvents()
 
+        if "toolbar" in kwargs and "logo" in kwargs:
+            raise ValueError("Conflicing properties set on plot: toolbar, logo.")
+
+        if "toolbar" in kwargs and "tools" in kwargs:
+            raise ValueError("Conflicing properties set on plot: toolbar, tools.")
+
+        if "toolbar" not in kwargs:
+            tools = kwargs.pop('tools', [])
+            logo = kwargs.pop('logo', 'normal')
+
+            kwargs["toolbar"] = Toolbar(tools=tools, logo=logo)
+
         if "border_fill" in kwargs and "border_fill_color" in kwargs:
             raise ValueError("Conflicting properties set on plot: border_fill, border_fill_color.")
 
         if "background_fill" in kwargs and "background_fill_color" in kwargs:
             raise ValueError("Conflicting properties set on plot: background_fill, background_fill_color.")
 
-        super(Plot, self).__init__(**kwargs)
+        super(LayoutDOM, self).__init__(**kwargs)
 
     def select(self, *args, **kwargs):
         ''' Query this object and all of its references for objects that
@@ -127,7 +119,6 @@ class Plot(Component):
         selector = _select_helper(args, kwargs)
 
         # Want to pass selector that is a dictionary
-        from ..plotting.helpers import _list_attr_splat
         return _list_attr_splat(find(self.references(), selector, {'plot': self}))
 
     def row(self, row, gridplot):
@@ -156,6 +147,76 @@ class Plot(Component):
         '''
         return self in gridplot.column(col)
 
+    def _axis(self, *sides):
+        objs = []
+        for s in sides:
+            objs.extend(getattr(self, s, []))
+        axis = [obj for obj in objs if isinstance(obj, Axis)]
+        return _list_attr_splat(axis)
+
+    @property
+    def xaxis(self):
+        """ Splattable list of :class:`~bokeh.models.axes.Axis` objects for the x dimension.
+
+        """
+        return self._axis("above", "below")
+
+    @property
+    def yaxis(self):
+        """ Splattable list of :class:`~bokeh.models.axes.Axis` objects for the y dimension.
+
+        """
+        return self._axis("left", "right")
+
+    @property
+    def axis(self):
+        """ Splattable list of :class:`~bokeh.models.axes.Axis` objects.
+
+        """
+        return _list_attr_splat(self.xaxis + self.yaxis)
+
+    @property
+    def legend(self):
+        """Splattable list of :class:`~bokeh.models.annotations.Legend` objects.
+
+        """
+        legends = [obj for obj in self.renderers if isinstance(obj, Legend)]
+        return _list_attr_splat(legends)
+
+    def _grid(self, dimension):
+        grid = [obj for obj in self.renderers if isinstance(obj, Grid) and obj.dimension==dimension]
+        return _list_attr_splat(grid)
+
+    @property
+    def xgrid(self):
+        """ Splattable list of :class:`~bokeh.models.grids.Grid` objects for the x dimension.
+
+        """
+        return self._grid(0)
+
+    @property
+    def ygrid(self):
+        """ Splattable list of :class:`~bokeh.models.grids.Grid` objects for the y dimension.
+
+        """
+        return self._grid(1)
+
+    @property
+    def grid(self):
+        """ Splattable list of :class:`~bokeh.models.grids.Grid` objects.
+
+        """
+        return _list_attr_splat(self.xgrid + self.ygrid)
+
+    @property
+    def tools(self):
+        return self.toolbar.tools
+
+    @tools.setter
+    def tools(self, tools):
+        self.toolbar.tools = tools
+
+
     def add_layout(self, obj, place='center'):
         ''' Adds an object to the plot in a specified place.
 
@@ -185,7 +246,7 @@ class Plot(Component):
             getattr(self, place).append(obj)
 
     def add_tools(self, *tools):
-        ''' Adds an tools to the plot.
+        ''' Adds tools to the plot.
 
         Args:
             *tools (Tool) : the tools to add to the Plot
@@ -203,7 +264,7 @@ class Plot(Component):
             tool.plot = self
             if hasattr(tool, 'overlay'):
                 self.renderers.append(tool.overlay)
-            self.tools.append(tool)
+            self.toolbar.tools.append(tool)
 
     def add_glyph(self, source_or_glyph, glyph=None, **kw):
         ''' Adds a glyph to the plot with associated data sources and ranges.
@@ -221,7 +282,7 @@ class Plot(Component):
             Glyph initializer.
 
         Returns:
-            Glyph
+            GlyphRenderer
 
         '''
         if glyph is not None:
@@ -313,7 +374,20 @@ class Plot(Component):
                                  for field, value in broken)
             return '%s [renderer: %s]' % (field_msg, self)
 
-    __deprecated_attributes__ = ('background_fill', 'border_fill')
+    @validation.warning(SNAPPED_TOOLBAR_ANNOTATIONS)
+    def _check_snapped_toolbar_and_axis(self):
+        if not self.toolbar_sticky: return
+        if self.toolbar_location is None: return
+
+        objs = getattr(self, self.toolbar_location)
+        if len(objs) > 0:
+            return str(self)
+
+    __deprecated_attributes__ = (
+        'background_fill', 'border_fill', 'logo', 'tools', 'responsive',
+        'title_text_baseline', 'title_text_align', 'title_text_alpha', 'title_text_color',
+        'title_text_font_style', 'title_text_font_size', 'title_text_font', 'title_standoff'
+    )
 
     x_range = Instance(Range, help="""
     The (default) data range of the horizontal dimension of the plot.
@@ -341,7 +415,7 @@ class Plot(Component):
     "seconds since epoch" instead of formatted dates
     """)
 
-    extra_x_ranges = Dict(String, Instance(Range1d), help="""
+    extra_x_ranges = Dict(String, Instance(Range), help="""
     Additional named ranges to make available for mapping x-coordinates.
 
     This is useful for adding additional axes.
@@ -357,30 +431,20 @@ class Plot(Component):
     Whether to use HiDPI mode when available.
     """)
 
-    title_standoff = Int(default=8, help="""
-    How far (in screen units) to place a title away from the central
-    plot region.
+    title = TitleProp(default=DEFAULT_TITLE, help="""
+    A title for the plot. Can be a text string or a Title annotation. Default is Title(text="").
     """)
 
-    title = String('', help="""
-    A title for the plot.
+    title_location = Enum(Location, default="above", help="""
+    Where the title will be located. Titles on the left or right side
+    will be rotated.
     """)
 
-    title_props = Include(TextProps, help="""
-    The %s for the plot title.
-    """)
-
-    title_text_align = Override(default='center')
-
-    title_text_baseline = Override(default='alphabetic')
-
-    title_text_font_size = Override(default={ 'value' : '20pt' })
-
     outline_props = Include(LineProps, help="""
     The %s for the plot border outline.
     """)
 
-    outline_line_color = Override(default="#aaaaaa")
+    outline_line_color = Override(default="#e5e5e5")
 
     renderers = List(Instance(Renderer), help="""
     A list of all renderers for this plot, including guides and annotations
@@ -391,15 +455,27 @@ class Plot(Component):
     setup is performed.
     """)
 
-    tools = List(Instance(Tool), help="""
-    A list of tools to add to the plot.
+    toolbar = Instance(Toolbar, help="""
+        The toolbar associated with this plot which holds all the tools.
+
+        The toolbar is automatically created with the plot.
+    """)
+
+    toolbar_location = Enum(Location, default="right", help="""
+    Where the toolbar will be located. If set to None, no toolbar
+    will be attached to the plot.
+    """)
+
+    toolbar_sticky = Bool(default=True, help="""
+    Stick the toolbar to the edge of the plot. Default: True. If False,
+    the toolbar will be outside of the axes, titles etc.
     """)
 
     tool_events = Instance(ToolEvents, help="""
     A ToolEvents object to share and report tool events.
     """)
 
-    left  = List(Instance(Renderer), help="""
+    left = List(Instance(Renderer), help="""
     A list of renderers to occupy the area to the left of the plot.
     """)
 
@@ -407,9 +483,7 @@ class Plot(Component):
     A list of renderers to occupy the area to the right of the plot.
     """)
 
-    # TODO (bev) LayoutBox here is a temporary workaround to the fact that
-    # plot titles are not proper renderers
-    above = List(Either(Instance(Renderer), Instance(LayoutBox)), help="""
+    above = List(Instance(Renderer), help="""
     A list of renderers to occupy the area above of the plot.
     """)
 
@@ -417,16 +491,6 @@ class Plot(Component):
     A list of renderers to occupy the area below of the plot.
     """)
 
-    toolbar_location = Enum(Location, help="""
-    Where the toolbar will be located. If set to None, no toolbar
-    will be attached to the plot.
-    """)
-
-    logo = Enum("normal", "grey", help="""
-    What version of the Bokeh logo to display on the toolbar. If
-    set to None, no logo will be displayed.
-    """)
-
     plot_height = Int(600, help="""
     Total height of the entire plot (including any axes, titles,
     border padding, etc.)
@@ -447,6 +511,130 @@ class Plot(Component):
 
     """)
 
+    background_props = Include(FillProps, help="""
+    The %s for the plot background style.
+    """)
+
+    background_fill_color = Override(default='#ffffff')
+
+    border_props = Include(FillProps, help="""
+    The %s for the plot border style.
+    """)
+
+    border_fill_color = Override(default='#ffffff')
+
+    min_border_top = Int(help="""
+    Minimum size in pixels of the padding region above the top of the
+    central plot region.
+
+    .. note::
+        This is a *minimum*. The padding region may expand as needed to
+        accommodate titles or axes, etc.
+
+    """)
+
+    min_border_bottom = Int(help="""
+    Minimum size in pixels of the padding region below the bottom of
+    the central plot region.
+
+    .. note::
+        This is a *minimum*. The padding region may expand as needed to
+        accommodate titles or axes, etc.
+
+    """)
+
+    min_border_left = Int(help="""
+    Minimum size in pixels of the padding region to the left of
+    the central plot region.
+
+    .. note::
+        This is a *minimum*. The padding region may expand as needed to
+        accommodate titles or axes, etc.
+
+    """)
+
+    min_border_right = Int(help="""
+    Minimum size in pixels of the padding region to the right of
+    the central plot region.
+
+    .. note::
+        This is a *minimum*. The padding region may expand as needed to
+        accommodate titles or axes, etc.
+
+    """)
+
+    min_border = Int(5, help="""
+    A convenience property to set all all the ``min_border_X`` properties
+    to the same value. If an individual border property is explicitly set,
+    it will override ``min_border``.
+    """)
+
+    h_symmetry = Bool(True, help="""
+    Whether the total horizontal padding on both sides of the plot will
+    be made equal (the left or right padding amount, whichever is larger).
+    """)
+
+    v_symmetry = Bool(False, help="""
+    Whether the total vertical padding on both sides of the plot will
+    be made equal (the top or bottom padding amount, whichever is larger).
+    """)
+
+    lod_factor = Int(10, help="""
+    Decimation factor to use when applying level-of-detail decimation.
+    """)
+
+    lod_threshold = Int(2000, help="""
+    A number of data points, above which level-of-detail downsampling may
+    be performed by glyph renderers. Set to ``None`` to disable any
+    level-of-detail downsampling.
+    """)
+
+    lod_interval = Int(300, help="""
+    Interval (in ms) during which an interactive tool event will enable
+    level-of-detail downsampling.
+    """)
+
+    lod_timeout = Int(500, help="""
+    Timeout (in ms) for checking whether interactive tool events are still
+    occurring. Once level-of-detail mode is enabled, a check is made every
+    ``lod_timeout`` ms. If no interactive tool events have happened,
+    level-of-detail mode is disabled.
+    """)
+
+    webgl = Bool(False, help="""
+    Whether WebGL is enabled for this plot. If True, the glyphs that
+    support this will render via WebGL instead of the 2D canvas.
+    """)
+
+    #
+    # DEPRECATED PROPERTIES
+    #
+
+    @property
+    def responsive(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('responsive', 'Plot.sizing_mode'))
+        return self.sizing_mode != "fixed"
+
+    @responsive.setter
+    def responsive(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('responsive', 'Plot.sizing_mode'))
+        warnings.warn("""
+        The 'responsive' property has been deprecated in 0.12.0. It has been
+        replaced by 'sizing_mode' which accepts one of five modes:
+
+            fixed, scale_width, scale_height, scale_both, stretch_both
+
+        'responsive = False' is the equivalent of 'sizing_mode = "fixed"'
+
+        'responsive = True' is the equivalent of 'sizing_mode = "scale_width"'
+        """)
+        if value is True:
+            self.sizing_mode = "scale_width"
+        elif value is False:
+            self.sizing_mode = "fixed"
+        else:
+            raise ValueError("Plot.responsive only accepts True or False, got: %r" % value)
+
     @property
     def background_fill(self):
         warnings.warn(
@@ -483,191 +671,113 @@ class Plot(Component):
             """)
         self.border_fill_color = color
 
-    background_props = Include(FillProps, help="""
-    The %s for the plot background style.
-    """)
+    @property
+    def logo(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('logo', 'Plot.toolbar.logo'))
+        return self.toolbar.logo
 
-    background_fill_color = Override(default='#ffffff')
+    @logo.setter
+    def logo(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('logo', 'Plot.toolbar.logo'))
+        self.toolbar.logo = value
 
-    border_props = Include(FillProps, help="""
-    The %s for the plot border style.
-    """)
+    @property
+    def title_standoff(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_standoff', 'Plot.title.offset'))
+        return self.title.offset
 
-    border_fill_color = Override(default='#ffffff')
+    @title_standoff.setter
+    def title_standoff(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_standoff', 'Plot.title.offset'))
+        self.title.offset = value
 
-    min_border_top = Int(50, help="""
-    Minimum size in pixels of the padding region above the top of the
-    central plot region.
+    @property
+    def title_text_font(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_font', 'Plot.title.text_font'))
+        return self.title.text_font
 
-    .. note::
-        This is a *minimum*. The padding region may expand as needed to
-        accommodate titles or axes, etc.
+    @title_text_font.setter
+    def title_text_font(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_font', 'Plot.title.text_font'))
+        self.title.text_font = value
 
-    """)
+    @property
+    def title_text_font_size(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_font_size', 'Plot.title.text_font_size'))
+        return self.title.text_font_size
 
-    min_border_bottom = Int(50, help="""
-    Minimum size in pixels of the padding region below the bottom of
-    the central plot region.
+    @title_text_font_size.setter
+    def title_text_font_size(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_font_size', 'Plot.title.text_font_size'))
+        self.title.text_font_size = value
 
-    .. note::
-        This is a *minimum*. The padding region may expand as needed to
-        accommodate titles or axes, etc.
+    @property
+    def title_text_font_style(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_font_style', 'Plot.title.text_font_style'))
+        return self.title.text_font_style
 
-    """)
+    @title_text_font_style.setter
+    def title_text_font_style(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_font_style', 'Plot.title.text_font_style'))
+        self.title.text_font_style = value
 
-    min_border_left = Int(50, help="""
-    Minimum size in pixels of the padding region to the left of
-    the central plot region.
+    @property
+    def title_text_color(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_color', 'Plot.title.text_color'))
+        return self.title.text_color
 
-    .. note::
-        This is a *minimum*. The padding region may expand as needed to
-        accommodate titles or axes, etc.
+    @title_text_color.setter
+    def title_text_color(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_color', 'Plot.title.text_color'))
+        self.title.text_color = value
 
-    """)
+    @property
+    def title_text_alpha(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_alpha', 'Plot.title.text_alpha'))
+        return self.title.text_alpha
 
-    min_border_right = Int(50, help="""
-    Minimum size in pixels of the padding region to the right of
-    the central plot region.
+    @title_text_alpha.setter
+    def title_text_alpha(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_alpha', 'Plot.title.text_alpha'))
+        self.title.text_alpha = value
 
-    .. note::
-        This is a *minimum*. The padding region may expand as needed to
-        accommodate titles or axes, etc.
+    @property
+    def title_text_align(self):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_align', 'Plot.title.align'))
+        warnings.warn("""``title_text_align`` was deprecated in 0.12.0 and is no longer
+        available on the new Title object. There is a new ``plot.title.title_align`` which is
+        similar but not exactly the same. The new ``title_align`` both positions and aligns the title.
+        If you need the exact ``title_text_align`` behavior, please add a title by creating a
+        Label (``bokeh.models.annotations.Label``) and manually adding
+        it to the plot by doing, for example ``plot.add_layout(Label(), 'above')``.
+        """)
+        return self.title.align
 
-    """)
+    @title_text_align.setter
+    def title_text_align(self, value):
+        warnings.warn(DEP_MSG_0_12_0 % ('title_text_align', 'Plot.title.align'))
+        warnings.warn("""``title_text_align`` was deprecated in 0.12.0 and is no longer
+        available on the new Title object. There is a new ``plot.title.title_align`` which is
+        similar but not exactly the same. The new ``title_align`` both positions and aligns the title.
+        If you need the exact ``title_text_align`` behavior, please add a title by creating a
+        Label (``bokeh.models.annotations.Label``) and manually adding
+        it to the plot by doing, for example ``plot.add_layout(Label(), 'above')``.
+        """)
+        self.title.align = value
 
-    min_border = Int(50, help="""
-    A convenience property to set all all the ``min_X_border`` properties
-    to the same value. If an individual border property is explicitly set,
-    it will override ``min_border``.
-    """)
+    @property
+    def title_text_baseline(self):
+        warnings.warn("""title_text_baseline was deprecated in 0.12.0 and is no longer
+        available on the new Title object. If you need to alter the text_baseline, please
+        add a title by creating a Label (``bokeh.models.annotations.Label``) and manually adding
+        it to the plot by doing, for example ``plot.add_layout(Label(), 'above')``.
+        """)
+        return None
 
-    h_symmetry = Bool(True, help="""
-    Whether the total horizontal padding on both sides of the plot will
-    be made equal (the left or right padding amount, whichever is larger).
-    """)
-
-
-    v_symmetry = Bool(False, help="""
-    Whether the total vertical padding on both sides of the plot will
-    be made equal (the top or bottom padding amount, whichever is larger).
-    """)
-
-    lod_factor = Int(10, help="""
-    Decimation factor to use when applying level-of-detail decimation.
-    """)
-
-    lod_threshold = Int(2000, help="""
-    A number of data points, above which level-of-detail downsampling may
-    be performed by glyph renderers. Set to ``None`` to disable any
-    level-of-detail downsampling.
-    """)
-
-    lod_interval = Int(300, help="""
-    Interval (in ms) during which an interactive tool event will enable
-    level-of-detail downsampling.
-    """)
-
-    lod_timeout = Int(500, help="""
-    Timeout (in ms) for checking whether interactive tool events are still
-    occurring. Once level-of-detail mode is enabled, a check is made every
-    ``lod_timeout`` ms. If no interactive tool events have happened,
-    level-of-detail mode is disabled.
-    """)
-
-    webgl = Bool(False, help="""
-    Whether WebGL is enabled for this plot. If True, the glyphs that
-    support this will render via WebGL instead of the 2D canvas.
-    """)
-
-    responsive = Bool(False, help="""
-    If True, the plot will automatically resize based on the size of its container. The
-    aspect ratio of the plot will be preserved, but ``plot_width`` and ``plot_height`` will
-    act only to set the initial aspect ratio.
-    .. warning::
-
-       The responsive setting is known not to work with HBox layout and may not work
-       in combination with other widgets or layouts.
-    """)
-
-
-class GridPlot(Component):
-    """ A 2D grid of plots rendered on separate canvases in an HTML table.
-
-    """
-
-    # TODO (bev) really, GridPlot should be a layout, not a Plot subclass
-    @validation.error(REQUIRED_RANGE)
-    def _check_required_range(self):
-        pass
-    @validation.warning(MISSING_RENDERERS)
-    def _check_missing_renderers(self):
-        pass
-
-    @validation.warning(NO_DATA_RENDERERS)
-    def _check_no_data_renderers(self):
-        pass
-
-    @validation.warning(EMPTY_LAYOUT)
-    def _check_empty_layout(self):
-        from itertools import chain
-        if not list(chain(self.children)):
-            return str(self)
-
-    children = List(List(Instance(Plot)), default=[[]], help="""
-    An array of plots to display in a grid, given as a list of lists of
-    Plot objects. To leave a position in the grid empty, pass None for
-    that position in the ``children`` list.
-    """)
-
-    border_space = Int(0, help="""
-    Distance (in pixels) between adjacent plots.
-    """)
-
-    toolbar_location = Enum(Location, default="left", help="""
-    Where the toolbar will be located. If set to None, no toolbar
-    will be attached to the plot.
-    """)
-
-    def select(self, *args, **kwargs):
-        ''' Query this object and all of its references for objects that
-        match the given selector. See Plot.select for detailed usage information.
-
-        Returns:
-            seq[Model]
-        '''
-
-        selector = _select_helper(args, kwargs)
-
-        # Want to pass selector that is a dictionary
-        from ..plotting.helpers import _list_attr_splat
-        return _list_attr_splat(find(self.references(), selector, {'gridplot': self}))
-
-    def column(self, col):
-        ''' Return a given column of plots from this GridPlot.
-
-        Args:
-            col (int) : index of the column to return
-
-        Returns:
-            seq[Plot] : column of plots
-
-        '''
-        try:
-            return [row[col] for row in self.children]
-        except:
-            return []
-
-    def row(self, row):
-        ''' Return a given row of plots from this GridPlot.
-
-        Args:
-            rwo (int) : index of the row to return
-
-        Returns:
-            seq[Plot] : row of plots
-
-        '''
-        try:
-            return self.children[row]
-        except:
-            return []
+    @title_text_baseline.setter
+    def title_text_baseline(self, value):
+        warnings.warn("""title_text_baseline was deprecated in 0.12.0 and is no longer
+        available on the new Title object. If you need to alter the text_baseline, please
+        add a title by creating a Label (``bokeh.models.annotations.Label``) and manually adding
+        it to the plot by doing, for example ``plot.add_layout(Label(), 'above')``.
+        """)
