@@ -19,6 +19,8 @@ import json
 from os.path import basename, join, relpath
 import re
 
+from six import string_types
+
 from . import __version__
 from .core.templates import JS_RESOURCES, CSS_RESOURCES
 from .settings import settings
@@ -81,7 +83,7 @@ class _SessionCoordinates(object):
         if self._app_path != '/' and self._app_path.endswith("/"):
             self._app_path = self._app_path[:-1] # chop off trailing slash
 
-        self._session_id = kwargs.get('session_id', None)
+        self._session_id = kwargs.get('session_id')
         # we lazy-generate the session_id so we can generate
         # it server-side when appropriate
 
@@ -202,8 +204,6 @@ class BaseResources(object):
     _default_root_dir = "."
     _default_root_url = DEFAULT_SERVER_HTTP_URL
 
-    logo_url = "http://bokeh.pydata.org/static/bokeh-transparent.png"
-
     def __init__(self, mode='inline', version=None, root_dir=None,
                  minified=True, log_level="info", root_url=None,
                  path_versioner=None, components=None):
@@ -276,6 +276,25 @@ class BaseResources(object):
         paths = [ join(bokehjs_dir, kind, file) for file in files ]
         return paths
 
+    def _collect_external_resources(self, resource_attr):
+        """ Collect external resources set on resource_attr attribute of all models."""
+
+        external_resources = []
+
+        for _, cls in sorted(Model.model_class_reverse_map.items(), key=lambda arg: arg[0]):
+            external = getattr(cls, resource_attr, None)
+
+            if isinstance(external, string_types):
+                if external not in external_resources:
+                    external_resources.append(external)
+            elif isinstance(external, list):
+                for e in external:
+                    if e not in external_resources:
+                        external_resources.append(e)
+
+        return external_resources
+
+
     def _cdn_urls(self):
         return _get_cdn_urls(self.components, self.version, self.minified)
 
@@ -348,7 +367,6 @@ class JSResources(BaseResources):
     Once configured, a Resource object exposes the following public attributes:
 
     Attributes:
-        logo_url : location of the BokehJS logo image
         css_raw : any raw CSS that needs to be places inside ``<style>`` tags
         css_files : URLs of any CSS files that need to be loaded by ``<link>`` tags
         messages : any informational messages concerning this configuration
@@ -364,6 +382,10 @@ class JSResources(BaseResources):
     @property
     def js_files(self):
         files, _ = self._resolve('js')
+
+        external_resources = self._collect_external_resources('__javascript__')
+        files.extend(external_resources)
+
         return files
 
     @property
@@ -407,7 +429,7 @@ class JSResources(BaseResources):
     }
 
     for (var i = 0; i < entry.length; i++) {
-      Bokeh.Collections.register_locations(Bokeh.require(entry[i]));
+      Bokeh.Models.register_locations(Bokeh.require(entry[i]));
     }
   } else {
     throw new Error("Cannot find Bokeh. You have to load it prior to loading plugins.");
@@ -505,7 +527,6 @@ class CSSResources(BaseResources):
     Once configured, a Resource object exposes the following public attributes:
 
     Attributes:
-        logo_url : location of the BokehJS logo image
         css_raw : any raw CSS that needs to be places inside ``<style>`` tags
         css_files : URLs of any CSS files that need to be loaded by ``<link>`` tags
         messages : any informational messages concerning this configuration
@@ -517,6 +538,10 @@ class CSSResources(BaseResources):
     @property
     def css_files(self):
         files, _ = self._resolve('css')
+
+        external_resources = self._collect_external_resources("__css__")
+        files.extend(external_resources)
+
         return files
 
     @property
@@ -568,7 +593,6 @@ class Resources(JSResources, CSSResources):
     Once configured, a Resource object exposes the following public attributes:
 
     Attributes:
-        logo_url : location of the BokehJS logo image
         js_raw : any raw JS that needs to be placed inside ``<script>`` tags
         css_raw : any raw CSS that needs to be places inside ``<style>`` tags
         js_files : URLs of any JS files that need to be loaded by ``<script>`` tags
