@@ -4,6 +4,7 @@ module.exports = {
   ToolEvents: require('./tool_events'),
   Arrow: require('../models/annotations/arrow'),
   BoxAnnotation: require('../models/annotations/box_annotation'),
+  ColorBar: require('../models/annotations/color_bar'),
   Label: require('../models/annotations/label'),
   LabelSet: require('../models/annotations/label_set'),
   Legend: require('../models/annotations/legend'),
@@ -69,18 +70,18 @@ module.exports = {
   Interpolator: require('../models/transforms/interpolator'),
   LinearInterpolator: require('../models/transforms/linear_interpolator'),
   StepInterpolator: require('../models/transforms/step_interpolator'),
-  Asterisk: require('../models/markers/asterisk'),
-  CircleCross: require('../models/markers/circle_cross'),
-  CircleX: require('../models/markers/circle_x'),
-  Cross: require('../models/markers/cross'),
-  Diamond: require('../models/markers/diamond'),
-  DiamondCross: require('../models/markers/diamond_cross'),
-  InvertedTriangle: require('../models/markers/inverted_triangle'),
-  Square: require('../models/markers/square'),
-  SquareCross: require('../models/markers/square_cross'),
-  SquareX: require('../models/markers/square_x'),
-  Triangle: require('../models/markers/triangle'),
-  X: require('../models/markers/x'),
+  Asterisk: require('../models/markers/index').Asterisk,
+  CircleCross: require('../models/markers/index').CircleCross,
+  CircleX: require('../models/markers/index').CircleX,
+  Cross: require('../models/markers/index').Cross,
+  Diamond: require('../models/markers/index').Diamond,
+  DiamondCross: require('../models/markers/index').DiamondCross,
+  InvertedTriangle: require('../models/markers/index').InvertedTriangle,
+  Square: require('../models/markers/index').Square,
+  SquareCross: require('../models/markers/index').SquareCross,
+  SquareX: require('../models/markers/index').SquareX,
+  Triangle: require('../models/markers/index').Triangle,
+  X: require('../models/markers/index').X,
   Plot: require('../models/plots/plot'),
   GMapPlot: require('../models/plots/gmap_plot'),
   DataRange1d: require('../models/ranges/data_range1d'),
