@@ -74,6 +74,7 @@ GlyphRendererView = (function(superClass) {
   GlyphRendererView.prototype.bind_bokeh_events = function() {
     this.listenTo(this.model, 'change', this.request_render);
     this.listenTo(this.mget('data_source'), 'change', this.set_data);
+    this.listenTo(this.mget('data_source'), 'patch', this.set_data);
     this.listenTo(this.mget('data_source'), 'stream', this.set_data);
     this.listenTo(this.mget('data_source'), 'select', this.request_render);
     if (this.hover_glyph != null) {
@@ -136,6 +137,9 @@ GlyphRendererView = (function(superClass) {
 
   GlyphRendererView.prototype.render = function() {
     var ctx, dtmap, dtmask, dtrender, dtselect, dttot, glsupport, glyph, i, indices, inspected, j, k, len, len1, lod_threshold, nonselected, nonselection_glyph, selected, selected_mask, selection_glyph, t0, tmap, tmask, trender, tselect;
+    if (this.model.visible === false) {
+      return;
+    }
     t0 = Date.now();
     glsupport = this.glyph.glglyph;
     tmap = Date.now();
@@ -158,8 +162,6 @@ GlyphRendererView = (function(superClass) {
         selected = indices;
       } else if (selected['1d'].indices.length > 0) {
         selected = selected['1d'].indices;
-      } else if (selected['2d'].indices.length > 0) {
-        selected = selected['2d'].indices;
       } else {
         selected = [];
       }
@@ -172,8 +174,6 @@ GlyphRendererView = (function(superClass) {
         inspected = indices;
       } else if (inspected['1d'].indices.length > 0) {
         inspected = inspected['1d'].indices;
-      } else if (inspected['2d'].indices.length > 0) {
-        inspected = inspected['2d'].indices;
       } else {
         inspected = [];
       }
